import django.apps

from . import ConnectorAppConfig, ConnectorAppMixin


class AppConfig(django.apps.AppConfig):
    name = 'passerelle.base'

    def ready(self):
        # once all applications are ready, go through them and mark them as
        # connectors if they have a get_connector_model() method or a model
        # that inherits from BaseResource.
        from .models import BaseResource

        for app in django.apps.apps.get_app_configs():
            connector_model = None
            if hasattr(app, 'get_connector_model'):
                connector_model = app.get_connector_model()
            else:
                for model in app.get_models():
                    if issubclass(model, BaseResource):
                        connector_model = model
                        app._connector_model = model
                        break
            if not connector_model:
                continue
            if app.__class__ is django.apps.AppConfig:
                # switch class if it's an application without a custom
                # appconfig.
                app.__class__ = ConnectorAppConfig
            else:
                # add mixin to base classes if it's an application with a
                # custom appconfig.
                app.__class__.__bases__ = (ConnectorAppMixin,) + app.__class__.__bases__


default_app_config = 'passerelle.base.AppConfig'
